exceptions.IOError

exceptions :: IOError :: Class IOError |
[hide private]
[frames] | no frames]

## Class IOError

    Exception --+
                |
    StandardError --+
                    |
     EnvironmentError --+
                        |
                       IOError

I/O operation failed.

Instance Methods | [hide private]
Inherited from `EnvironmentError`: `__init__`, `__str__` Inherited from `Exception`: `__getitem__`